@@ -19,13 +19,12 @@ from sphinx.writers import html5
 
 import sphindexer as idxr
 from sphindexer.rack import UNIT_CLSF, UNIT_TERM, UNIT_SBTM
-from sphindexer.glossary import BaseGlossary
 
 
 __copyright__ = 'Copyright (C) 2021 @koKkekoh'
 __license__ = 'BSD 2-Clause License'
 __author__  = '@koKekkoh'
-__version__ = '0.31.2' # 2021-12-09
+__version__ = '0.31.3' # 2022-02-24
 __url__     = 'https://qiita.com/tags/sphinxcotrib.kana_text'
 
 
@@ -41,7 +40,7 @@ _dflt_separator = r'\|'
 _dflt_option_marker = r'\^'
 
 def parser_for_kana_text(separator, option_marker):
-    """かな|単語^オプション」を取り出す正規表現を作る.
+    r"""かな|単語^オプション」を取り出す正規表現を作る.
 
     :param separator: 「かな」と「単語」を分ける文字の指定.
     :type separator: str
@@ -53,7 +52,7 @@ def parser_for_kana_text(separator, option_marker):
     doctest::
 
        >>> parser_for_kana_text(r'\|', r'\^')
-       re.compile('([ \\u3000]*)((.*?)\\\\|)*([^\\\\^]*)((\\\\^)([0-9a-z]*)?)?')
+       re.compile('([ \u3000]*)((.*?)\\|)*([^\\^]*)((\\^)([0-9a-z]*)?)?')
     """
 
     ahead = r'([ 　]*)'
@@ -801,7 +800,7 @@ def setup(app) -> Dict[str, Any]:
     # 索引の表示はExtHTMLBuilderで行う
 
     # glossaryディレクティブ
-    app.add_directive_to_domain("std", "glossary", BaseGlossary, True)
+    #app.add_directive_to_domain("std", "glossary", idxr.Glossary, True)
 
     # HTML出力
     app.add_builder(ExtHTMLBuilder, True)
